
/**
 MIT License

 Copyright (c) 2024 innocces

 Power by TARO-HOOKS
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

exports.ENV_TYPE = void 0;
(function (ENV_TYPE) {
    ENV_TYPE["WEAPP"] = "WEAPP";
    ENV_TYPE["WEB"] = "WEB";
    ENV_TYPE["RN"] = "RN";
    ENV_TYPE["SWAN"] = "SWAN";
    ENV_TYPE["ALIPAY"] = "ALIPAY";
    ENV_TYPE["TT"] = "TT";
    ENV_TYPE["QQ"] = "QQ";
    ENV_TYPE["JD"] = "JD";
})(exports.ENV_TYPE || (exports.ENV_TYPE = {}));
const ENV = TARO_ENV;
const ISWEAPP = ENV === exports.ENV_TYPE.WEAPP;
const ISWEB = ENV === exports.ENV_TYPE.WEB;
const ISRN = ENV === exports.ENV_TYPE.RN;
const ISSWAN = ENV === exports.ENV_TYPE.SWAN;
const ISALIPAY = ENV === exports.ENV_TYPE.ALIPAY;
const ISTT = ENV === exports.ENV_TYPE.TT;
const ISQQ = ENV === exports.ENV_TYPE.QQ;
const ISJD = ENV === exports.ENV_TYPE.JD;
const PREFIX = '🎮[taro-hooks]';
const INJECTKEY = '$$inject';
const FRAMEWORK = __TARO_HOOKS_VUE__
    ? 'vue'
    : __TARO_HOOKS_REACT__
        ? 'react'
        : null;
const ISVUE = FRAMEWORK === 'vue';
const ISREACT = FRAMEWORK === 'react';
const PATH2LABEL = {
    basic: '基础',
    device: '设备',
    env: '环境判断',
    feedback: '操作反馈',
    layout: '布局',
    media: '媒体',
    network: '网络',
    wechat: '小程序',
};
const BANNER = `
/**
 MIT License

 Copyright (c) ${new Date().getFullYear()} innocces

 Power by TARO-HOOKS
 */
`;

const baseLogStyle = 'color: #8843e7; font-weight: bold;';
function logCtor(style = '') {
    return (...args) => {
        args.forEach((logMsg) => {
            if (typeof logMsg === 'string') {
                console.debug(`%c${PREFIX}---${logMsg}`, baseLogStyle + style);
            }
            else {
                console.debug(PREFIX, '---', logMsg);
            }
        });
    };
}
const log = logCtor();
const logError = logCtor('color: #d14; text-decoration: underline;');

function isObject(value) {
    return value !== null && typeof value === 'object';
}
function isFunction(value) {
    return typeof value === 'function';
}
function isString(value) {
    return typeof value === 'string';
}
function isBoolean(value) {
    return typeof value === 'boolean';
}
function isNumber(value) {
    return typeof value === 'number';
}
function isUndef(value) {
    return typeof value === 'undefined';
}
function strictOf(value, type) {
    return (Object.prototype.toString.call(value) === `[object ${camelIndex(type)}]`);
}
function camelIndex(input) {
    return isString(input)
        ? input.replace(/^([a-z]{1})/, (searchValue, matchValue) => matchValue ? matchValue?.toUpperCase?.() : null)
        : input;
}
/**
 * single check isRef func
 * @param {any} value any value for check
 * @returns {boolean} isRef??
 */
function isRef(value) {
    return !!(value && value.__v_isRef === true);
}

/**
 * major job for shims differs between react and vue
 */
/**
 * due to useState vue.ver use customRef to simulate. so need auto release value to caculate
 * @param {any} state check state
 * @returns {any}
 */
const escapeState = (state) => {
    return isRef(state) ? state.value : state;
};

exports.BANNER = BANNER;
exports.ENV = ENV;
exports.FRAMEWORK = FRAMEWORK;
exports.INJECTKEY = INJECTKEY;
exports.ISALIPAY = ISALIPAY;
exports.ISJD = ISJD;
exports.ISQQ = ISQQ;
exports.ISREACT = ISREACT;
exports.ISRN = ISRN;
exports.ISSWAN = ISSWAN;
exports.ISTT = ISTT;
exports.ISVUE = ISVUE;
exports.ISWEAPP = ISWEAPP;
exports.ISWEB = ISWEB;
exports.PATH2LABEL = PATH2LABEL;
exports.PREFIX = PREFIX;
exports.camelIndex = camelIndex;
exports.escapeState = escapeState;
exports.isBoolean = isBoolean;
exports.isFunction = isFunction;
exports.isNumber = isNumber;
exports.isObject = isObject;
exports.isRef = isRef;
exports.isString = isString;
exports.isUndef = isUndef;
exports.log = log;
exports.logCtor = logCtor;
exports.logError = logError;
exports.strictOf = strictOf;
//# sourceMappingURL=index.js.map
